@@ -14,10 +14,6 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#if defined(_MSC_VER)
-	#pragma warning ( disable: 4231 4251 4275 4786 )
-#endif
-
 
 #include <log4cxx/logstring.h>
 #include <log4cxx/pattern/relativetimepatternconverter.h>
@@ -41,7 +37,7 @@ RelativeTimePatternConverter::RelativeTimePatternConverter() :
 PatternConverterPtr RelativeTimePatternConverter::newInstance(
 	const std::vector<LogString>& /* options */)
 {
-	static PatternConverterPtr def(new RelativeTimePatternConverter());
+	static PatternConverterPtr def = std::make_shared<RelativeTimePatternConverter>();
 	return def;
 }
 
