@@ -20,11 +20,6 @@
 
 #include <log4cxx/writerappender.h>
 
-#if defined(_MSC_VER)
-	#pragma warning ( push )
-	#pragma warning ( disable: 4251 )
-#endif
-
 namespace log4cxx
 {
 
@@ -36,7 +31,7 @@ namespace log4cxx
 class LOG4CXX_EXPORT ConsoleAppender : public WriterAppender
 {
 	private:
-		LogString target;
+		struct ConsoleAppenderPriv;
 
 	public:
 		DECLARE_LOG4CXX_OBJECT(ConsoleAppender)
@@ -45,30 +40,53 @@ class LOG4CXX_EXPORT ConsoleAppender : public WriterAppender
 		LOG4CXX_CAST_ENTRY_CHAIN(AppenderSkeleton)
 		END_LOG4CXX_CAST_MAP()
 
+		/**
+		* A <code>stdout</code> log event appender.
+		*
+		* See also #setLayout and #setTarget.
+		*/
 		ConsoleAppender();
+
+		/**
+		* A <code>stdout</code> log event appender formatted using \c layout.
+		*
+		* @param layout formats a log event
+		*/
 		ConsoleAppender(const LayoutPtr& layout);
+
+		/**
+		* A \c target log event appender formatted using \c layout.
+		*
+		* @param layout formats a log event
+		* @param target the value provided by #getSystemOut or #getSystemErr
+		*/
 		ConsoleAppender(const LayoutPtr& layout, const LogString& target);
 		~ConsoleAppender();
 
 
 		/**
-		*  Sets the value of the <b>target</b> property. Recognized values
-		*  are "System.out" and "System.err". Any other value will be
-		*  ignored.
+		*  Use \c newValue for the <b>target</b> property.
+		*
+		* @param newValue the value provided by #getSystemOut or #getSystemErr
 		* */
-		void setTarget(const LogString& value);
+		void setTarget(const LogString& newValue);
 
 		/**
-		* Returns the current value of the <b>target</b> property. The
-		* default value of the option is "System.out".
-		*
-		* See also #setTarget.
-		* */
+		* @returns the current value of the <b>target</b> property.
+		*/
 		LogString getTarget() const;
 
-		void activateOptions(log4cxx::helpers::Pool& p);
-		void setOption(const LogString& option, const LogString& value);
+		void activateOptions(helpers::Pool& p) override;
+		void setOption(const LogString& option, const LogString& value) override;
+
+		/**
+		*  @returns the name recognised as <code>stdout</code>.
+		*/
 		static const LogString& getSystemOut();
+
+		/**
+		*  @returns the name recognised as <code>stderr</code>.
+		*/
 		static const LogString& getSystemErr();
 
 
@@ -79,9 +97,5 @@ class LOG4CXX_EXPORT ConsoleAppender : public WriterAppender
 LOG4CXX_PTR_DEF(ConsoleAppender);
 }  //namespace log4cxx
 
-#if defined(_MSC_VER)
-	#pragma warning (pop)
-#endif
-
 #endif //_LOG4CXX_CONSOLE_APPENDER_H
 
