@@ -1,6 +1,6 @@
 /* findfile.cpp: finding files
 
-   Copyright (C) 1996-2022 Christian Schenk
+   Copyright (C) 1996-2024 Christian Schenk
 
    This file is part of the MiKTeX Core Library.
 
@@ -103,7 +103,7 @@ bool SessionImpl::SearchFileSystem(const string& fileName, const char* pathPatte
 
   for (vector<PathName>::const_iterator it = directories.begin(); (!found || all) && it != directories.end(); ++it)
   {
-    PathName path(*it, PathName(fileName));
+    PathName path(*it / fileName);
     if (CheckCandidate(path, nullptr, callback))
     {
       found = true;
@@ -147,7 +147,7 @@ bool SessionImpl::FindFileInDirectories(const string& fileName, const vector<Pat
     PathName pathWD;
     for (unsigned idx = 0; (!found || all) && GetWorkingDirectory(idx, pathWD); ++idx)
     {
-      PathName path = pathWD / PathName(fileName);
+      PathName path = pathWD / fileName;
       path.MakeFullyQualified();
       if (CheckCandidate(path, nullptr, callback))
       {
@@ -156,7 +156,7 @@ bool SessionImpl::FindFileInDirectories(const string& fileName, const vector<Pat
         // 2015-01-15
         if (idx == 0)
         {
-          MIKTEX_ASSERT(PathName::Compare(pathWD, PathName().SetToCurrentDirectory()) == 0);
+          MIKTEX_ASSERT(PathName::Equals(pathWD, PathName().SetToCurrentDirectory()));
           path = fileName;
         }
 #endif
@@ -359,12 +359,12 @@ bool SessionImpl::FindFileByType(const string& fileName, FileType fileType, bool
       bool renew = false;
       if (IsSharedSetup())
       {
-        PathName pathPackagesIni(GetSpecialPath(SpecialPath::CommonInstallRoot), PathName(MIKTEX_PATH_PACKAGES_INI));
+        PathName pathPackagesIni(GetSpecialPath(SpecialPath::CommonInstallRoot) / MIKTEX_PATH_PACKAGES_INI);
         renew = IsNewer(pathPackagesIni, result[0]);
       }
       if (!renew && !IsAdminMode() && (!IsSharedSetup() || GetUserConfigRoot() != GetCommonConfigRoot()))
       {
-        PathName pathPackagesIni(GetSpecialPath(SpecialPath::UserInstallRoot), PathName(MIKTEX_PATH_PACKAGES_INI));
+        PathName pathPackagesIni(GetSpecialPath(SpecialPath::UserInstallRoot) / MIKTEX_PATH_PACKAGES_INI);
         renew = IsNewer(pathPackagesIni, result[0]);
       }
       if (renew)
@@ -601,7 +601,7 @@ bool SessionImpl::FindPkFile(const string& fontName, const string& mfMode, int d
     return true;
   }
 
-  if (mfMode.empty() || StringCompare(mfMode.c_str(), "modeless", true) != 0)
+  if (mfMode.empty() || StringCompare(mfMode, "modeless", true) != 0)
   {
     // RECURSION
     return FindPkFile(fontName, "modeless", dpi, result);
