@@ -262,7 +262,7 @@ public:
   {
     MiKTeX::TeXAndFriends::IInputOutput* inputOutput = GetInputOutput();
     Reallocate(inputOutput->nameoffile(), fileName.GetLength() + 1);
-    MiKTeX::Util::StringUtil::CopyString(inputOutput->nameoffile(), fileName.GetLength() + 1, fileName.GetData());
+    MiKTeX::Util::StringUtil::CopyCeeString(inputOutput->nameoffile(), fileName.GetLength() + 1, fileName.GetData());
     inputOutput->namelength() = static_cast<C4P::C4P_signed32>(fileName.GetLength());
   }
 
