@@ -2,7 +2,7 @@
 ** PsSpecialHandler.cpp                                                 **
 **                                                                      **
 ** This file is part of dvisvgm -- a fast DVI to SVG converter          **
-** Copyright (C) 2005-2023 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2024 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -31,7 +31,7 @@
 #include "Message.hpp"
 #include "PathClipper.hpp"
 #include "PSPattern.hpp"
-#include "PSPreviewFilter.hpp"
+#include "PSPreviewHandler.hpp"
 #include "PsSpecialHandler.hpp"
 #include "SpecialActions.hpp"
 #include "SVGElement.hpp"
@@ -54,7 +54,7 @@ string PsSpecialHandler::BITMAP_FORMAT;
 bool PsSpecialHandler::EMBED_BITMAP_DATA = false;
 
 
-PsSpecialHandler::PsSpecialHandler () : _psi(this), _previewFilter(_psi)
+PsSpecialHandler::PsSpecialHandler () : _psi(this), _previewHandler(_psi)
 {
 	_psi.setImageDevice(BITMAP_FORMAT);
 }
@@ -134,9 +134,8 @@ void PsSpecialHandler::enterBodySection () {
 		// Check for information generated by preview.sty. If the tightpage options
 		// was set, don't execute the bop-hook but allow the PS filter to read
 		// the bbox data present at the beginning of the page.
-		_psi.setFilter(&_previewFilter);
-		_previewFilter.activate();
-		if (!_previewFilter.tightpage())
+		_previewHandler.init();
+		if (!_previewHandler.tightpage())
 			_psi.execute("userdict/bop-hook known{bop-hook}if\n", false);
 	}
 }
@@ -166,9 +165,7 @@ void PsSpecialHandler::executeAndSync (istream &is, bool updatePos) {
 		_actions->getColor().getRGB(r, g, b);
 		ostringstream oss;
 		oss << '\n' << r << ' ' << g << ' ' << b << " setrgbcolor ";
-		PSFilter *filter = _psi.setFilter(nullptr);  // don't apply any filters here
 		_psi.execute(oss.str(), false);
-		_psi.setFilter(filter);
 	}
 	_psi.execute(is);
 	if (updatePos) {
@@ -555,14 +552,15 @@ void PsSpecialHandler::dviBeginPage (unsigned int pageno, SpecialActions &action
 
 
 void PsSpecialHandler::dviEndPage (unsigned, SpecialActions &actions) {
+	_previewHandler.readDataFromStack();
 	BoundingBox bbox;
-	if (_previewFilter.getBoundingBox(bbox)) {  // is there any data written by preview package?
+	if (_previewHandler.getBoundingBox(bbox)) {  // is there any data written by preview package?
 		double w=0, h=0, d=0;
 		if (actions.getBBoxFormatString() == "preview" || actions.getBBoxFormatString() == "min") {
 			if (actions.getBBoxFormatString() == "preview") {
-				w = max(0.0, _previewFilter.width());
-				h = max(0.0, _previewFilter.height());
-				d = max(0.0, _previewFilter.depth());
+				w = max(0.0, _previewHandler.width());
+				h = max(0.0, _previewHandler.height());
+				d = max(0.0, _previewHandler.depth());
 				actions.bbox() = bbox;
 				Message::mstream() << "\napplying bounding box set by";
 			}
@@ -572,7 +570,7 @@ void PsSpecialHandler::dviEndPage (unsigned, SpecialActions &actions) {
 				d = max(0.0, actions.bbox().maxY());
 				Message::mstream() << "\ncomputing extents based on data set by";
 			}
-			Message::mstream() << " preview package (version " << _previewFilter.version() << ")\n";
+			Message::mstream() << " preview package (version " << _previewHandler.version() << ")\n";
 
 			// apply page transformations to box extents
 			Matrix pagetrans = actions.getPageTransformation();
