@@ -135,5 +135,5 @@ private:
   class SetupWizard* sheet = nullptr;
 
 private:
-  shared_ptr<Session> session = Session::Get();
+  shared_ptr<Session> session = MIKTEX_SESSION();
 };
