@@ -32,7 +32,7 @@ with LuaTeX; if not, see <http://www.gnu.org/licenses/>.
 
 #include "luatex_svnversion.h"
 #if defined(MIKTEX)
-#  include <miktex/Core/Paths.h> // MIKTEX_PREFIX
+#include <miktex/Core/Paths.h> // MIKTEX_PREFIX
 #endif
 
 extern int load_luatex_core_lua (lua_State * L);
@@ -92,6 +92,7 @@ const_string LUATEX_IHELP[] = {
     "   --interaction=STRING          set interaction mode (STRING=batchmode/nonstopmode/scrollmode/errorstopmode)",
     "   --job-name=STRING             set the job name to STRING",
     "   --lua=FILE                    load and execute a lua initialization script",
+    "   --luadebug                    enable lua debug library",
     "   --mktex=FMT                   enable automatic generation (FMT one of: tex, tfm)",
     "   --no-c-style-errors           disable file:line:error style messages",
     "   --no-mktex=FMT                disable automatic generation (FMT one of: tex, tfm)",
@@ -104,6 +105,7 @@ const_string LUATEX_IHELP[] = {
     "   --recorder                    enable filename recorder",
     "   --restrict-write18            restrict system commands to a list of commands given in the configuration data store",
     "   --safer                       disable easily exploitable lua commands",
+    "   --luadebug                    enable lua debug library",
     "   --synctex=NUMBER              enable synctex",
     "   --undump=FORMAT               load the format file FORMAT",
     "   --utc                         init time to UTC",
@@ -146,6 +148,7 @@ const_string LUATEX_IHELP[] = {
     "   --jobname=STRING              set the job name to STRING",
     "   --kpathsea-debug=NUMBER       set path searching debugging flags according to the bits of NUMBER",
     "   --lua=FILE                    load and execute a lua initialization script",
+    "   --luadebug                    enable lua debug library",
     "   --[no-]mktex=FMT              disable/enable mktexFMT generation (FMT=tex/tfm)",
     "   --nosocket                    disable the lua socket library",
     "   --no-socket                   disable the lua socket library",
@@ -284,6 +287,7 @@ int nosocket_cli_option = 0;
 int yessocket_cli_option = 0; 
 int socket_bitmask = 0; 
 int utc_option = 0;
+int luadebug_option = 0;
 
 /*tex We use a bitmask for the socket library: |0000| and |1xxx| implies |--nosocket|,
   otherwise the socket library is enabled. Default value is |0000|, i.e. |--nosocket|.
@@ -341,6 +345,7 @@ static struct option long_options[] = {
     {"jithash", 1, 0, 0},
 #endif
     {"safer", 0, &safer_option, 1},
+    {"luadebug", 0, &luadebug_option, 1},
     {"utc", 0, &utc_option, 1},
     {"nosocket", 0, &nosocket_cli_option, 1},
     {"no-socket", 0, &nosocket_cli_option, 1},
@@ -1167,6 +1172,7 @@ void lua_initialize(int ac, char **av)
     haltonerrorp = false;
     haltingonerrorp = false;
     tracefilenames = 1;
+    traceextranewline = 0;
     dump_name = NULL;
     /*tex
         In the next option 0 means ``disable Synchronize TeXnology''. The
@@ -1185,6 +1191,7 @@ void lua_initialize(int ac, char **av)
         restrictedshell = false;
         safer_option = 0;
 	nosocket_option = 0;
+	luadebug_option = true;
     }
     /*tex
         Get the current locale (it should be |C|) and save |LC_CTYPE|, |LC_COLLATE|
@@ -1334,6 +1341,8 @@ void lua_initialize(int ac, char **av)
         get_lua_boolean("texconfig", "check_dvi_total_pages", &check_dvi_total_pages);
         /*tex |prohibit_file_trace| (boolean) */
         get_lua_boolean("texconfig", "trace_file_names", &tracefilenames);
+        /*tex |trace_extra_newline| (boolean) */
+        get_lua_boolean("texconfig", "trace_extra_newline", &traceextranewline);
         /*tex |file_line_error| */
         get_lua_boolean("texconfig", "file_line_error", &filelineerrorstylep);
         /*tex |halt_on_error| */
@@ -1397,6 +1406,19 @@ void lua_initialize(int ac, char **av)
         kpse_init = 1;
         fix_dumpname();
     }
+    if (output_directory) {
+      xputenv ("TEXMF_OUTPUT_DIRECTORY", output_directory);
+    } else if (getenv ("TEXMF_OUTPUT_DIRECTORY")) {
+#if defined(MIKTEX)
+      miktex_web2c_set_output_directory(getenv("TEXMF_OUTPUT_DIRECTORY"));
+#else
+      output_directory = getenv ("TEXMF_OUTPUT_DIRECTORY");
+#endif
+    }
+    /* the lua debug library is enabled if shell escape permits everything */
+    if (shellenabledp && restrictedshell != 1) {
+      luadebug_option = 1 ;      
+    }
     /*tex Here we load luatex-core.lua which takes care of some protection on demand. */
     if (load_luatex_core_lua(Luas)) {
         fprintf(stderr, "Error in execution of luatex-core.lua .\n");
